import sys

if sys.version_info < (3, 11):
    from .jimdb_ap_redis import JimdbApRedis
else:
    JimdbApRedis = None

from .base_redis import BaseRedis
from .local_redis import LocalRedis

__all__ = [
    "JimdbApRedis",
    "BaseRedis",
    "LocalRedis",
]
